summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qlistview_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qlistview_imp.h')
-rw-r--r--kjsembed/qtbindings/qlistview_imp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kjsembed/qtbindings/qlistview_imp.h b/kjsembed/qtbindings/qlistview_imp.h
index f201c179..0ded4900 100644
--- a/kjsembed/qtbindings/qlistview_imp.h
+++ b/kjsembed/qtbindings/qlistview_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TTQListView;
+class TQListView;
/**
* Namespace containing the KJSEmbed library.
@@ -17,7 +17,7 @@ class TTQListView;
namespace KJSEmbed {
/**
* Wrapper class for TTQListView methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -111,7 +111,7 @@ public:
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TTQListView *toTQListView( KJS::Object &object );
+ static TQListView *toTQListView( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -210,7 +210,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TTQListView *instance; // Temp
+ TQListView *instance; // Temp
int id;
bool cons;
};
@@ -17,7 +17,7 @@ class TTQListView;
namespace KJSEmbed {
/**
- * Wrapper class for TTQListView methods.
+ * Wrapper class for TQListView methods.
*
* @author Richard Moore, rich@kde.org